==> 1.5.1.tar.gz: lib/src/widgets/video_feed/video_feed_platform_view.dart <==
import 'package:fw_flutter_sdk/src/utils/model_utils/ad_configuration_util.dart';

import '../../models/fw_error.dart';
import '../../models/ad_configuration.dart';
import '../../models/video_feed_configuration.dart';
import '../../models/video_feed_mode.dart';
import '../../models/video_feed_source.dart';
import '../../models/video_player_configuration.dart';
import 'video_feed_platform_handler.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

import '../../utils/model_utils/video_feed_configuration_util.dart';
import '../../utils/model_utils/video_feed_mode_util.dart';
import '../../utils/model_utils/video_feed_source_util.dart';
import '../../utils/model_utils/video_player_configuration_util.dart';

typedef VideoFeedPlatformViewLoadFinishedCallback = void Function(
    FWError? error);
typedef VideoFeedPlatformViewCreatedCallback = void Function(
    VideoFeedPlatformHandler handler);

class VideoFeedPlatformView extends StatefulWidget {
  final VideoFeedSource source;
  final String? channel;
  final String? playlist;
  final String? playlistGroup;
  final Map<String, List<String>>? dynamicContentParameters;
  final VideoFeedMode mode;
  final VideoFeedConfiguration? videoFeedConfiguration;
  final VideoPlayerConfiguration? videoPlayerConfiguration;
  final AdConfiguration? adConfiguration;
  final bool useHybridCompositionForAndroid;
  final VideoFeedPlatformViewLoadFinishedCallback?
      onVideoFeedPlatformViewLoadFinished;
  final VideoFeedPlatformViewCreatedCallback? onVideoFeedPlatformViewCreated;

  const VideoFeedPlatformView({
    Key? key,
    required this.source,
    this.channel,
    this.playlist,
    this.playlistGroup,
    this.dynamicContentParameters,
    this.mode = VideoFeedMode.row,
    this.videoFeedConfiguration,
    this.videoPlayerConfiguration,
    this.adConfiguration,
    this.useHybridCompositionForAndroid = false,
    this.onVideoFeedPlatformViewLoadFinished,
    this.onVideoFeedPlatformViewCreated,
  }) : super(key: key);

  @override
  _VideoFeedPlatformViewState createState() => _VideoFeedPlatformViewState();
}

class _VideoFeedPlatformViewState extends State<VideoFeedPlatformView> {
  final String _viewType = "fw.fondor.view/video_feed";
  VideoFeedPlatformHandler? _handler;

  @override
  void initState() {
    super.initState();
  }

  @override
  void didUpdateWidget(covariant VideoFeedPlatformView oldWidget) {
    super.didUpdateWidget(oldWidget);
    _handler?.updateWidget(widget);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return _buildAndroidPlatformView(context);
    } else {
      return _buildIOSPlatformView(context);
    }
  }

  Widget _buildAndroidPlatformView(BuildContext context) {
    final creationParams = _generateCreationParams();
    final layoutDirection =
        Directionality.maybeOf(context) ?? TextDirection.ltr;
    const creationParamsCodec = StandardMessageCodec();

    if (widget.useHybridCompositionForAndroid) {
      return PlatformViewLink(
        viewType: _viewType,
        surfaceFactory:
            (BuildContext context, PlatformViewController controller) {
          return AndroidViewSurface(
            controller: controller as AndroidViewController,
            gestureRecognizers: _generateGestureRecognizers(),
            hitTestBehavior: PlatformViewHitTestBehavior.opaque,
          );
        },
        onCreatePlatformView: (PlatformViewCreationParams params) {
          return PlatformViewsService.initSurfaceAndroidView(
            id: params.id,
            viewType: _viewType,
            layoutDirection: layoutDirection,
            creationParams: creationParams,
            creationParamsCodec: creationParamsCodec,
            onFocus: () {
              params.onFocusChanged(true);
            },
          )
            ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
            ..addOnPlatformViewCreatedListener(_onPlatformViewCreated)
            ..create();
        },
      );
    } else {
      return AndroidView(
        viewType: _viewType,
        onPlatformViewCreated: _onPlatformViewCreated,
        layoutDirection: layoutDirection,
        creationParams: creationParams,
        creationParamsCodec: creationParamsCodec,
        gestureRecognizers: _generateGestureRecognizers(),
      );
    }
  }

  Widget _buildIOSPlatformView(BuildContext context) {
    Map<String, dynamic> creationParams = _generateCreationParams();
    final layoutDirection =
        Directionality.maybeOf(context) ?? TextDirection.ltr;

    return UiKitView(
      viewType: _viewType,
      onPlatformViewCreated: _onPlatformViewCreated,
      layoutDirection: layoutDirection,
      creationParams: creationParams,
      creationParamsCodec: const StandardMessageCodec(),
      gestureRecognizers: _generateGestureRecognizers(),
    );
  }

  Map<String, dynamic> _generateCreationParams() {
    Map<String, dynamic> creationParams = <String, dynamic>{
      "source": VideoFeedSourceUtil.convertToRawFeedSource(widget.source),
    };

    if (widget.channel != null) {
      creationParams["channel"] = widget.channel!;
    }

    if (widget.playlist != null) {
      creationParams["playlist"] = widget.playlist!;
    }

    if (widget.playlistGroup != null) {
      creationParams["playlistGroup"] = widget.playlistGroup!;
    }

    if (widget.dynamicContentParameters != null) {
      creationParams["dynamicContentParameters"] =
          widget.dynamicContentParameters!;
    }

    creationParams["mode"] =
        VideoFeedModeUtil.convertToRawFeedMode(widget.mode);

    if (widget.videoFeedConfiguration != null) {
      creationParams["videoFeedConfiguration"] =
          VideoFeedConfigurationUtil.toJson(widget.videoFeedConfiguration!);
    }

    if (widget.videoPlayerConfiguration != null) {
      creationParams["videoPlayerConfiguration"] =
          VideoPlayerConfigurationUtil.toJson(widget.videoPlayerConfiguration!);
    }

    if (widget.adConfiguration != null) {
      creationParams["adConfiguration"] =
          AdConfigurationUtil.toJson(widget.adConfiguration!);
    }

    return creationParams;
  }

  Set<Factory<OneSequenceGestureRecognizer>> _generateGestureRecognizers() {
    return <Factory<OneSequenceGestureRecognizer>>{
      Factory<OneSequenceGestureRecognizer>(
        () => widget.mode == VideoFeedMode.row
            ? HorizontalDragGestureRecognizer()
            : VerticalDragGestureRecognizer(),
      ),
    };
  }

  void _onPlatformViewCreated(int viewId) {
    _handler = VideoFeedPlatformHandler(viewId: viewId, widget: widget);
    widget.onVideoFeedPlatformViewCreated?.call(_handler!);
  }
}

==> 2.0.4.tar.gz: lib/src/widgets/video_feed/video_feed_platform_view.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

import '../../models/ad_configuration.dart';
import '../../models/fw_error.dart';
import '../../models/video_feed_configuration.dart';
import '../../models/video_feed_mode.dart';
import '../../models/video_feed_source.dart';
import '../../models/video_player_configuration.dart';
import '../../utils/model_utils/ad_configuration_util.dart';
import '../../utils/model_utils/video_feed_configuration_util.dart';
import '../../utils/model_utils/video_player_configuration_util.dart';
import '../mixins/android_platform_view_mixin.dart';
import 'video_feed_platform_handler.dart';

typedef VideoFeedPlatformViewLoadFinishedCallback = void Function(
    FWError? error);
typedef VideoFeedPlatformViewCreatedCallback = void Function(
    VideoFeedPlatformHandler handler);

class VideoFeedPlatformView extends StatefulWidget {
  final VideoFeedSource source;
  final String? channel;
  final String? playlist;
  final String? playlistGroup;
  final Map<String, List<String>>? dynamicContentParameters;
  final String? hashtagFilterExpression;
  final VideoFeedMode mode;
  final bool? enablePictureInPicture;
  final VideoFeedConfiguration? videoFeedConfiguration;
  final VideoPlayerConfiguration? videoPlayerConfiguration;
  final AdConfiguration? adConfiguration;
  final VideoFeedPlatformViewLoadFinishedCallback?
      onVideoFeedPlatformViewLoadFinished;
  final VideoFeedPlatformViewCreatedCallback? onVideoFeedPlatformViewCreated;

  const VideoFeedPlatformView({
    Key? key,
    required this.source,
    this.channel,
    this.playlist,
    this.playlistGroup,
    this.dynamicContentParameters,
    this.hashtagFilterExpression,
    this.mode = VideoFeedMode.row,
    this.enablePictureInPicture,
    this.videoFeedConfiguration,
    this.videoPlayerConfiguration,
    this.adConfiguration,
    this.onVideoFeedPlatformViewLoadFinished,
    this.onVideoFeedPlatformViewCreated,
  }) : super(key: key);

  @override
  State<VideoFeedPlatformView> createState() => _VideoFeedPlatformViewState();
}

class _VideoFeedPlatformViewState extends State<VideoFeedPlatformView>
    with AndroidPlatformViewMixin {
  final String _viewType = "fw.fondor.view/video_feed";
  Completer<VideoFeedPlatformHandler> _handlerCompleter = Completer();

  @override
  void initState() {
    super.initState();
  }

  @override
  void didUpdateWidget(covariant VideoFeedPlatformView oldWidget) {
    super.didUpdateWidget(oldWidget);
    // FWLoggerUtil.log("VideoFeedPlatformView didUpdateWidget");
    _handlerCompleter.future.then((handler) {
      handler.updateWidget(widget);
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return buildAndroidPlatformView(_buildAndroidPlatformView);
    } else {
      return _buildIOSPlatformView(context);
    }
  }

  Widget _buildAndroidPlatformView(BuildContext context, ValueKey key) {
    final creationParams = _generateCreationParams();
    const layoutDirection = TextDirection.ltr;
    const creationParamsCodec = StandardMessageCodec();
    return PlatformViewLink(
      key: key,
      viewType: _viewType,
      surfaceFactory:
          (BuildContext context, PlatformViewController controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: _generateGestureRecognizers(),
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: _viewType,
          layoutDirection: layoutDirection,
          creationParams: creationParams,
          creationParamsCodec: creationParamsCodec,
          onFocus: () {
            params.onFocusChanged(true);
          },
        )
          ..addOnPlatformViewCreatedListener(params.onPlatformViewCreated)
          ..addOnPlatformViewCreatedListener(_onPlatformViewCreated)
          ..create();
      },
    );
  }

  Widget _buildIOSPlatformView(BuildContext context) {
    Map<String, dynamic> creationParams = _generateCreationParams();
    const layoutDirection = TextDirection.ltr;

    return UiKitView(
      viewType: _viewType,
      onPlatformViewCreated: _onPlatformViewCreated,
      layoutDirection: layoutDirection,
      creationParams: creationParams,
      creationParamsCodec: const StandardMessageCodec(),
      gestureRecognizers: _generateGestureRecognizers(),
    );
  }

  Map<String, dynamic> _generateCreationParams() {
    Map<String, dynamic> creationParams = <String, dynamic>{
      "source": widget.source.name,
    };

    if (widget.channel != null) {
      creationParams["channel"] = widget.channel!;
    }

    if (widget.playlist != null) {
      creationParams["playlist"] = widget.playlist!;
    }

    if (widget.playlistGroup != null) {
      creationParams["playlistGroup"] = widget.playlistGroup!;
    }

    if (widget.dynamicContentParameters != null) {
      creationParams["dynamicContentParameters"] =
          widget.dynamicContentParameters!;
    }

    if (widget.hashtagFilterExpression != null) {
      creationParams["hashtagFilterExpression"] =
          widget.hashtagFilterExpression!;
    }

    creationParams["mode"] = widget.mode.name;

    if (widget.enablePictureInPicture != null) {
      creationParams["enablePictureInPicture"] = widget.enablePictureInPicture!;
    }

    if (widget.videoFeedConfiguration != null) {
      creationParams["videoFeedConfiguration"] =
          VideoFeedConfigurationUtil.toJson(widget.videoFeedConfiguration!);
    }

    if (widget.videoPlayerConfiguration != null) {
      creationParams["videoPlayerConfiguration"] =
          VideoPlayerConfigurationUtil.toJson(widget.videoPlayerConfiguration!);
    }

    if (widget.adConfiguration != null) {
      creationParams["adConfiguration"] =
          AdConfigurationUtil.toJson(widget.adConfiguration!);
    }

    if (defaultTargetPlatform == TargetPlatform.android) {
      creationParams["marginRight"] = androidMarginRight;
    }

    return creationParams;
  }

  Set<Factory<OneSequenceGestureRecognizer>> _generateGestureRecognizers() {
    return <Factory<OneSequenceGestureRecognizer>>{
      Factory<OneSequenceGestureRecognizer>(
        () => widget.mode == VideoFeedMode.row
            ? HorizontalDragGestureRecognizer()
            : VerticalDragGestureRecognizer(),
      ),
    };
  }

  void _onPlatformViewCreated(int viewId) {
    final handler = VideoFeedPlatformHandler(viewId: viewId, widget: widget);
    if (_handlerCompleter.isCompleted) {
      _handlerCompleter = Completer();
    }
    _handlerCompleter.complete(handler);
    widget.onVideoFeedPlatformViewCreated?.call(handler);
  }
}
